local L = LibStub("AceLocale-3.0"):GetLocale("ExtGuildUI", true);

-- ********** variables for storing previous values **********
local OLD_CONFIG = {
    ["show_load_message"] = false,
};
-- ***********************************************************

local CONFIG_SHOWN = false;

--========================================
-- Setting up the config frame
--========================================
function ExtGuildUIConfig_OnLoad(self)
    self.name = L["ADDON_TITLE"];
    self.okay = function(self) ExtGuildUIConfig_Close(); end;
    self.cancel = function(self) ExtGuildUIConfig_Cancel(); end;
    self.refresh = function(self) ExtGuildUIConfig_Refresh(); end;
    self.default = function(self) ExtGuildUIConfig_SetDefaults(); end;
    InterfaceOptions_AddCategory(self);

    ExtGuildUIConfigTitle:SetText(string.format(L["VERSION_TEXT"], "|cffffffffv" .. EXTGUILDUI_VERSION));

    -- ********** General Options **********

    ExtGuildUIConfig_GeneralContainerTitle:SetText(L["CONFIG_HEADING_GENERAL"]);

	ExtGuildUIConfig_GeneralContainer_ShowLoadMsgText:SetText(L["OPTION_STARTUP_MESSAGE"]);
	ExtGuildUIConfig_GeneralContainer_ShowLoadMsg.tooltip = L["OPTION_STARTUP_MESSAGE_TOOLTIP"];

end

--==================================================
-- Handle when the configuration is opened
--==================================================
function ExtGuildUIConfig_OnShow()
    if (CONFIG_SHOWN) then return; end
    ExtGuildUIConfig_StoreCurrentSettings();
    CONFIG_SHOWN = true;
end

--========================================
-- Sets the values of the controls to
-- reflect currently loaded settings
--========================================
function ExtGuildUIConfig_Refresh()
    ExtGuildUIConfig_OnShow();
	ExtGuildUIConfig_GeneralContainer_ShowLoadMsg:SetChecked(EXTGUILDUI_DATA['config']['show_load_message']);
end

--==================================================
-- Store current settings to restore if the user
-- presses cancel
--==================================================
function ExtGuildUIConfig_StoreCurrentSettings()
    ExtGuildUIConfig_StoreOldSetting("show_load_message");
end

--==================================================
-- Copies a config setting to the 'backup' table
--==================================================
function ExtGuildUIConfig_StoreOldSetting(key)
    if (EXTGUILDUI_DATA['config'][key]) then
        OLD_CONFIG[key] = EXTGUILDUI_DATA['config'][key];
    end
end

--==================================================
-- Restores a config setting from the backup table
--==================================================
function ExtGuildUIConfig_RestoreConfigSetting(key)
    if (OLD_CONFIG[key]) then
        EXTGUILDUI_DATA['config'][key] = OLD_CONFIG[key];
    end
end

--========================================
-- Closing the config window
--========================================
function ExtGuildUIConfig_Close()
    CONFIG_SHOWN = false;
end

--==================================================
-- Handle clicking the Cancel button; restore
-- all settings to their previous values
--==================================================
function ExtGuildUIConfig_Cancel()
    ExtGuildUIConfig_RestoreConfigSetting("show_load_message");
    ExtGuildUIConfig_Close();
end

--========================================
-- Handler for checking/unchecking
-- checkbox(es)
--========================================
function ExtGuildUIConfig_CheckBox_OnClick(self, id)
	if (id == 1) then
		if (self:GetChecked()) then
		    EXTGUILDUI_DATA['config']['show_load_message'] = true;
		else
		    EXTGUILDUI_DATA['config']['show_load_message'] = false;
		end

	end
end

--========================================
-- Handler for mousing over options
-- on the config window
--========================================
function ExtGuildUIConfig_Option_OnEnter(self)
	if (self.tooltip) then
        GameTooltip:SetOwner(self, "ANCHOR_NONE");
		GameTooltip:SetPoint("TOPLEFT", self:GetName(), "BOTTOMLEFT", -10, -4);
        GameTooltip:SetText(self.tooltip, 1, 1, 1);
        GameTooltip:Show();
	end
end

--========================================
-- Moving the mouse away from config
-- options
--========================================
function ExtGuildUIConfig_Option_OnLeave(self)
	GameTooltip:Hide();
end
